import pandas as pd
from office365.sharepoint.client_context import ClientContext
from office365.runtime.auth.user_credential import UserCredential

def get_list_view_test(username, password, sharepoint_site, list_name, view_name="All Items"):
    conn = ClientContext(sharepoint_site).with_credentials(UserCredential(username, password))
    web = conn.web
    conn.load(web)
    conn.execute_query()
    target_list = conn.web.lists.get_by_title(list_name)
    
    # Load fields to get their internal names
    fields = target_list.fields.get().execute_query()
    field_mapping = {field.internal_name: field.title for field in fields}
    
    view = target_list.views.get_by_title(view_name)
    view_fields = view.view_fields.get().execute_query()
    
    visible_fields = {field: field_mapping[field] for field in view_fields if field_mapping.get(field)}
    items = target_list.items.get().execute_query()
    data = []
    for item in items:
        item_data = {visible_fields[field]: item.properties.get(field) for field in visible_fields}
        data.append(item_data)
    df = pd.DataFrame(data)
    return df



from setuptools import setup, find_packages
from pathlib import Path

# Read the contents of your README file
README = Path('README.md').read_text()

setup(
    name='sharepoint_to_df',
    version='0.3.1',  # Update the version number
    description='A library to fetch SharePoint list data and return it as a Pandas DataFrame.',
    long_description=README,  # Include the content of README.md
    long_description_content_type='text/markdown',  # Indicate that the README is in Markdown format
    author='Mutaz Younes',
    author_email='mutazyounes@gmail.com',
    packages=find_packages(),
    install_requires=[
        'pandas',
        'office365-rest-python-client'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
